#ifndef NT2_INCLUDE_FUNCTIONS_LO_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LO_HPP_INCLUDED

#include <nt2/bitwise/include/functions/lo.hpp>

#endif
